Struct amazon_sp_messaging::models::get_messaging_action_response::GetMessagingActionResponse
source · [−]pub struct GetMessagingActionResponse {
pub _links: Option<Box<GetMessagingActionResponseLinks>>,
pub _embedded: Option<Box<GetMessagingActionResponseEmbedded>>,
pub payload: Option<Box<MessagingAction>>,
pub errors: Option<Vec<Error>>,
}Expand description
GetMessagingActionResponse : Describes a messaging action that can be taken for an order. Provides a JSON Hypertext Application Language (HAL) link to the JSON schema document that describes the expected input.
Fields
_links: Option<Box<GetMessagingActionResponseLinks>>_embedded: Option<Box<GetMessagingActionResponseEmbedded>>payload: Option<Box<MessagingAction>>errors: Option<Vec<Error>>A list of error responses returned when a request is unsuccessful.
Implementations
sourceimpl GetMessagingActionResponse
impl GetMessagingActionResponse
sourcepub fn new() -> GetMessagingActionResponse
pub fn new() -> GetMessagingActionResponse
Describes a messaging action that can be taken for an order. Provides a JSON Hypertext Application Language (HAL) link to the JSON schema document that describes the expected input.